<?php
// $Id: gsitemap.php,v 1.1.2.1 2007/04/23 02:11:47 darrenoh Exp $

/**
 * @addtogroup hooks
 * @{
 */

/**
 * Define additional links to add to the site map.
 *
 * This hook allows modules to add additional links to the site map. Links
 * may be associated with nodes, terms, or users, as shown in the example.
 *
 * @param $type
 *   If given, the type of link to associate additional links with.
 * @param $excludes
 *   If given, the criterion for excluding links.
 * @return
 *   An array of links or an empty array.
 */
function hook_gsitemap($type = NULL, $excludes = "''") {
  $additional = array();
  switch ($type) {
    case 'node':
      if (module_exists('comment')) {
        $maxcomments = db_result(db_query('SELECT MAX(comment_count) FROM {node_comment_statistics}'));
      }
      else {
        $maxcomments = 0;
      }
      $result = db_query("
        SELECT n.nid, n.changed, p.pages, g.previously_changed, g.priority_override
        FROM {node} n
        INNER JOIN {paging} p
        ON n.nid = p.nid
        LEFT JOIN {gsitemap} g
        ON n.nid = g.nid
        WHERE n.status > 0
        AND (g.priority_override >= 0 OR g.priority_override IS NULL)
        AND n.type NOT IN ($excludes)
        AND p.pages > 1
      ");
      while ($node = db_fetch_object($result)) {
        $age = time() - $node->changed;
        $interval = 0;
        if (max($age, $interval) < 3600) {
          $frequency = 'always';
        }
        elseif (max($age, $interval) < 86400) {
          $frequency = 'hourly';
        }
        elseif (max($age, $interval) < 604800) {
          $frequency = 'daily';
        }
        elseif (max($age, $interval) < 2419200) {
          $frequency = 'weekly';
        }
        elseif (max($age, $interval) < 29030400) {
          $frequency = 'monthly';
        }
        elseif (max($age, $interval) < 100000000) {
          $frequency = 'yearly';
        }
        else {
          $frequency = 'never';
        }
        if (isset($node->previously_changed)) {
          $interval = $node->changed - $node->previously_changed;
        }
        for ($count = 1; $count < $node->pages; ++ $count) {
          $entry = array(
            'nid' => $node->nid,
            '#loc' => url('node/'. $node->nid, "page=0,$count", NULL, TRUE),
            '#lastmod' => gmdate('Y-m-d\TH:i:s+00:00', $node->changed),
            '#changefreq' => $frequency,
            '#priority' => _gsitemap_calc_priority($node, $maxcomments),
          );
          $additional[] = $entry;
        }
      }
      break;
    case 'term':
    case 'user':
    default:
  }
  return $additional;
}

/**
 * @} End of "addtogroup hooks".
 */

